==========
User Guide
==========

.. toctree::
    :maxdepth: 2

    introduction.rst
    architecture.rst
    state-machines.rst
    resource-monitoring.rst
    ../cli/index
    ../restapi/index
    Blazar Dashboard (external link) <https://docs.openstack.org/blazar-dashboard/latest/index.html>
